@@ -1,7 +1,9 @@
 package App::CSVUtils;
 
-our $DATE = '2019-11-14'; # DATE
-our $VERSION = '0.024'; # VERSION
+# AUTHOR
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'App-CSVUtils'; # DIST
+our $VERSION = '0.025'; # VERSION
 
 use 5.010001;
 use strict;
@@ -272,7 +274,7 @@ our %args_sort_fields = (
     },
     sort_example => {
         schema => ['array*', of=>'str*',
-                   'x.perl.coerce_rules' => ['str_comma_sep']],
+                   'x.perl.coerce_rules' => ['From_str::comma_sep']],
     },
 );
 
@@ -2043,7 +2045,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.024 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-11-14.
+This document describes version 0.025 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-11-29.
 
 =head1 DESCRIPTION
 
@@ -3583,10 +3585,10 @@ L<App::LTSVUtils>
 L<App::SerializeUtils>
 
 
-L<csv-select-row>.
-
 L<csvgrep>.
 
+L<csv-select-row>.
+
 L<setop>.
 
 L<csv-split>.
